@@ -35,7 +35,8 @@ impl<C: ChannelType + Default + Copy, const N: usize> BufferedWs281x<C, N> {
         };
 
         unsafe { riot_sys::ws281x_init(dev.as_mut_ptr(), &params) }
-                .negative_to_error().expect("Init failed");
+            .negative_to_error()
+            .expect("Init failed");
 
         Self {
             buffer: [Default::default(); N],
@@ -48,8 +49,13 @@ impl<C: ChannelType, const N: usize> BufferedWs281x<C, N> {
     pub fn write(&mut self) {
         unsafe {
             riot_sys::ws281x_prepare_transmission(crate::inline_cast_mut(&mut self.dev as *mut _));
-            riot_sys::ws281x_write_buffer(&mut self.dev, &self.buffer as *const _ as *const core::ffi::c_void, (N * core::mem::size_of::<C>())
-                                          .try_into().expect("Buffer exceeds experssible range"));
+            riot_sys::ws281x_write_buffer(
+                &mut self.dev,
+                &self.buffer as *const _ as *const core::ffi::c_void,
+                (N * core::mem::size_of::<C>())
+                    .try_into()
+                    .expect("Buffer exceeds experssible range"),
+            );
             riot_sys::ws281x_end_transmission(crate::inline_cast_mut(&mut self.dev as *mut _));
         }
     }
